==> hal-processors-0.3.1-sources.jar: org/jboss/hal/processor/mbui/Attribute.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.hal.processor.mbui;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Harald Pehl
 */
public class Attribute {

    private final String name;
    private final String provider;
    private final String validationHandler;
    private final String suggestHandler;
    private final int position;
    private final List<String> suggestHandlerTemplates;

    Attribute(final String name, final String provider, final String validationHandler, final String suggestHandler,
            final int position) {
        this.name = name;
        this.provider = Handlebars.stripHandlebar(provider);
        this.validationHandler = Handlebars.stripHandlebar(validationHandler);
        this.suggestHandler = Handlebars.stripHandlebar(suggestHandler);
        this.position = position;
        this.suggestHandlerTemplates = new ArrayList<>();
    }

    public String getName() {
        return name;
    }

    public String getProvider() {
        return provider;
    }

    public int getPosition() {
        return position;
    }

    public String getValidationHandler() {
        return validationHandler;
    }

    public String getSuggestHandler() {
        return suggestHandler;
    }

    public List<String> getSuggestHandlerTemplates() {
        return suggestHandlerTemplates;
    }

    void addSuggestHandlerTemplate(String template) {
        suggestHandlerTemplates.add(template);
    }
}

==> hal-processors-0.9.0-sources.jar: org/jboss/hal/processor/mbui/Attribute.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.hal.processor.mbui;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Harald Pehl
 */
public class Attribute {

    private final String name;
    private final String formItem;
    private final String provider;
    private final String validationHandler;
    private final String suggestHandler;
    private final List<String> suggestHandlerTemplates;

    Attribute(final String name, final String provider, final String formItem,
            final String validationHandler, final String suggestHandler) {
        this.name = name;
        this.provider = Handlebars.stripHandlebar(provider);
        this.formItem = Handlebars.stripHandlebar(formItem);
        this.validationHandler = Handlebars.stripHandlebar(validationHandler);
        this.suggestHandler = Handlebars.stripHandlebar(suggestHandler);
        this.suggestHandlerTemplates = new ArrayList<>();
    }

    public String getName() {
        return name;
    }

    public String getFormItem() {
        return formItem;
    }

    public String getProvider() {
        return provider;
    }

    public String getValidationHandler() {
        return validationHandler;
    }

    public String getSuggestHandler() {
        return suggestHandler;
    }

    public List<String> getSuggestHandlerTemplates() {
        return suggestHandlerTemplates;
    }

    void addSuggestHandlerTemplate(String template) {
        suggestHandlerTemplates.add(template);
    }
}
